@@ -11,6 +11,8 @@
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/JourneyRequest>
 
+#include <KCalendarCore/Calendar>
+
 #include <QObject>
 #include <QVariant>
 
@@ -23,6 +25,7 @@ class QTimer;
 class LiveDataManager;
 class ReservationManager;
 class TransferManager;
+class DocumentManager;
 
 /** C++ side logic for timeline delegates. */
 class TimelineDelegateController : public QObject
@@ -31,6 +34,7 @@ class TimelineDelegateController : public QObject
     Q_PROPERTY(QObject* reservationManager READ reservationManager WRITE setReservationManager NOTIFY setupChanged)
     Q_PROPERTY(QObject* liveDataManager READ liveDataManager WRITE setLiveDataManager NOTIFY setupChanged)
     Q_PROPERTY(QObject* transferManager READ transferManager WRITE setTransferManager NOTIFY setupChanged)
+    Q_PROPERTY(QObject* documentManager READ documentManager WRITE setDocumentManager NOTIFY setupChanged)
     Q_PROPERTY(QString batchId READ batchId WRITE setBatchId NOTIFY batchIdChanged)
 
     Q_PROPERTY(bool isCurrent READ isCurrent NOTIFY currentChanged)
@@ -60,7 +64,11 @@ class TimelineDelegateController : public QObject
     /** A KPublicTransport::JourneyRequest for the current journey.
      *  This includes the current element as well as any immediately connected following elements.
      */
-    Q_PROPERTY(KPublicTransport::JourneyRequest journeyRequest READ journeyRequest NOTIFY contentChanged) // TODO technically notification also depends on other elements, so similar to previousLocationChanged
+    Q_PROPERTY(KPublicTransport::JourneyRequest journeyRequestFull READ journeyRequestFull NOTIFY contentChanged) // TODO technically notification also depends on other elements, so similar to previousLocationChanged
+    /** A KPublicTransport::JourneyRequest for the current element.
+     *  This does not include any connected following elements.
+     */
+    Q_PROPERTY(KPublicTransport::JourneyRequest journeyRequestOne READ journeyRequestOne NOTIFY contentChanged)
 
     /** Inbound connection is unlikely to work. */
     Q_PROPERTY(bool connectionWarning READ connectionWarning NOTIFY connectionWarningChanged)
@@ -81,6 +89,8 @@ public:
     void setLiveDataManager(QObject *liveDataMgr);
     QObject* transferManager() const;
     void setTransferManager(QObject *transferMgr);
+    QObject* documentManager() const;
+    void setDocumentManager(QObject *documentMgr);
 
     QString batchId() const;
     void setBatchId(const QString &batchId);
@@ -99,8 +109,9 @@ public:
     bool isLocationChange() const;
     bool isPublicTransport() const;
 
-    KPublicTransport::JourneyRequest journeyRequest() const;
-    Q_INVOKABLE void applyJourney(const QVariant &journey);
+    KPublicTransport::JourneyRequest journeyRequestFull() const;
+    KPublicTransport::JourneyRequest journeyRequestOne() const;
+    Q_INVOKABLE void applyJourney(const QVariant &journey, bool includeFollowing);
 
     bool connectionWarning() const;
     bool isCanceled() const;
@@ -112,6 +123,9 @@ public:
 
     int documentCount() const;
 
+    /** Add the current reservation to the calendar @p cal. */
+    Q_INVOKABLE void addToCalendar(KCalendarCore::Calendar *cal);
+
 Q_SIGNALS:
     void setupChanged();
     void batchIdChanged();
@@ -138,6 +152,7 @@ private:
     ReservationManager *m_resMgr = nullptr; // ### should this be static?
     LiveDataManager *m_liveDataMgr = nullptr;
     TransferManager *m_transferMgr = nullptr;
+    DocumentManager *m_documentMgr = nullptr;
     QString m_batchId;
     bool m_isCurrent = false;
 
